Documentation
¶
Index ¶
Constants ¶
const ( // CurVer is the currently supported software version CurVer int = 1 )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Hdr ¶
type Hdr struct {
// Ver is wire format version. If the protocol changes, for example, record format changes, or
// end of transfer is added at the end of the transfer, etc, this number will go up by 1.
// Backward compatibility may or may not be maintained.
Ver int
// Hash is the type of hash
Hash dlhash.Type
// EncDec is the type of hash
EncDec encdec.Type
}
Hdr contains the transfer information, it is the first part transferred.
Click to show internal directories.
Click to hide internal directories.